@@ -1,7 +1,7 @@
 """
 Type annotations for elb service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/literals/)
 
 Usage::
 
@@ -25,9 +25,12 @@ __all__ = (
     "DescribeLoadBalancersPaginatorName",
     "InstanceDeregisteredWaiterName",
     "InstanceInServiceWaiterName",
+    "ElasticLoadBalancingServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -36,6 +39,7 @@ DescribeAccountLimitsPaginatorName = Literal["describe_account_limits"]
 DescribeLoadBalancersPaginatorName = Literal["describe_load_balancers"]
 InstanceDeregisteredWaiterName = Literal["instance_deregistered"]
 InstanceInServiceWaiterName = Literal["instance_in_service"]
+ElasticLoadBalancingServiceName = Literal["elb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -324,5 +328,40 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["describe_account_limits", "describe_load_balancers"]
 WaiterName = Literal["any_instance_in_service", "instance_deregistered", "instance_in_service"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
